==> php80-nextcloud-26.0.5.tgz: share/nextcloud/apps/theming/l10n/el.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Το όνομα που δόθηκε είναι πολύ μεγάλο",
    "The given web address is too long" : "Η διεύθυνση ιστοσελίδας που δόθηκε είναι πολύ μεγάλη.",
    "The given web address is not a valid URL" : "Η διεύθυνση ιστοχώρου δεν είναι έγκυρη URL",
    "The given legal notice address is too long" : "Η διεύθυνση ειδοποίησης είναι πολύ μεγάλη",
    "The given legal notice address is not a valid URL" : "Η διεύθυνση νομικής ειδοποίησης δεν είναι έγκυρη διεύθυνση URL",
    "The given privacy policy address is too long" : "Η διεύθυνση πολιτικής απορρήτου είναι πολύ μεγάλη",
    "The given privacy policy address is not a valid URL" : "Η διεύθυνση πολιτικής απορρήτου δεν είναι έγκυρη διεύθυνση URL",
    "The given slogan is too long" : "Το ρητό που δόθηκε είναι πολύ μεγάλο",
    "The given color is invalid" : "Δόθηκε μη έγκυρο χρώμα",
    "Saved" : "Αποθηκεύτηκαν",
    "The file was uploaded" : "Το αρχείο μεταφορτώθηκε",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία upload_max_filesize στο php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία MAX_FILE_SIZE που καθορίστηκε στην φόρμα HTML.",
    "The file was only partially uploaded" : "Το αρχείο μεταφορτώθηκε εν μέρει",
    "No file was uploaded" : "Δεν μεταφορτώθηκε κάποιο αρχείο",
    "Missing a temporary folder" : "Λείπει κάποιος προσωρινός φάκελος",
    "Could not write file to disk" : "Αδυναμία εγγραφής αρχείου στον δίσκο",
    "A PHP extension stopped the file upload" : "Ένα πρόσθετο PHP διέκοψε την μεταφόρτωση του αρχείου",
    "No file uploaded" : "Δεν έχει μεταφορτωθεί αρχείο",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Χρησιμοποιείτε ήδη προσαρμοσμένο θέμα. Οι ρυθμίσεις της εφαρμογής Θέματα μπορεί να αντικατασταθούν από αυτό.",
    "Theming" : "Προσαρμογή θέματος",
    "Appearance and accessibility" : "Εμφάνιση και προσβασιμότητα",
    "Dark theme with high contrast mode" : "Σκούρο θέμα με λειτουργία υψηλής αντίθεσης",
    "Enable dark high contrast mode" : "Ενεργοποίηση σκοτεινής λειτουργίας υψηλής αντίθεσης",
    "Similar to the high contrast mode, but with dark colours." : "Παρόμοιο με τη λειτουργία υψηλής αντίθεσης, αλλά με σκούρα χρώματα.",
    "Dark theme" : "Σκούρο θέμα",
    "Enable dark theme" : "Ενεργοποίηση σκούρου θέματος",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ένα σκούρο θέμα που διευκολύνει τα μάτια σας μειώνοντας τη συνολική ακτινοβολία και φωτεινότητα.",
    "System default theme" : "Προεπιλεγμένο θέμα συστήματος",
    "Enable the system default" : "Ενεργοποίηση προεπιλογής συστήματος",
    "Using the default system appearance." : "Χρήση της προεπιλεγμένης εμφάνισης του συστήματος.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "Enable dyslexia font" : "Ενεργοποίηση γραμματοσειράς για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη λάθη που προκαλεί η δυσλεξία στην ανάγνωση",
    "High contrast mode" : "Λειτουργία υψηλής αντίθεσης",
    "Enable high contrast mode" : "Ενεργοποίηση λειτουργίας υψηλής αντίθεσης",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Λειτουργία με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Light theme" : "Φωτεινό θέμα",
    "Enable the default light theme" : "Ενεργοποίηση φωτεινού θέματος",
    "The default light appearance." : "Η προεπιλεγμένη ανοιχτόχρωμη εμφάνιση.",
    "Legal notice" : "Νομική ειδοποίηση",
    "Privacy policy" : "Πολιτική Απορρήτου",
    "Adjust the Nextcloud theme" : "Προσαρμόστε το θέμα του Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Η προσαρμογή θέματος καθιστά δυνατή την εύκολη προσαρμογή της εμφάνισης της εγκατάστασής σας καθώς και των υποστηριζόμενων πελατών. Θα είναι ορατή για όλους τους χρήστες.",
    "Advanced options" : "Επιλογές για προχωρημένους",
    "Name" : "Όνομα",
    "Web link" : "Σύνδεσμος ιστού",
    "a safe home for all your data" : "μια ασφαλής τοποθεσία για όλα σας τα δεδομένα",
    "Slogan" : "Ρητό",
    "Color" : "Χρώμα",
    "Logo" : "Λογότυπο",
    "Upload new logo" : "Μεταφόρτωση νέου λογοτύπου",
    "Background and login image" : "Παρασκήνιο και εικόνα εισόδου",
    "Legal notice link" : "Σύνδεσμος νομικής ειδοποίησης",
    "Privacy policy link" : "Σύνδεσμος πολιτικής απορρήτου",
    "Header logo" : "Λογότυπο επικεφαλίδας",
    "Upload new header logo" : "Μεταφόρτωση νέου λογοτύπου επικεφαλίδας",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Μεταφόρτωση νέου favicon",
    "User settings" : "Ρυθμίσεις χρήστη",
    "Disable user theming" : "Απενεργοποίηση θεμάτων χρήστη",
    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Σε ορισμένες περιπτώσεις, οι συντομεύσεις πληκτρολογίου μπορεί να επηρεάσουν τα εργαλεία προσβασιμότητας. Για να επιτρέψετε τη σωστή εστίαση στο εργαλείο σας, μπορείτε να απενεργοποιήσετε όλες τις συντομεύσεις πληκτρολογίου εδώ. Αυτό θα απενεργοποιήσει επίσης όλες τις διαθέσιμες συντομεύσεις στις εφαρμογές.",
    "Disable all keyboard shortcuts" : "Απενεργοποίηση των συντομεύσεων πληκτρολογίου",
    "Background" : "Φόντο",
    "Set a custom background" : "Ορισμός προσαρμοσμένου φόντου",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η  πρόσβαση από όλους είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με τις {guidelines}Προδιαγραφές πρόσβασης περιεχομένου Ιστού{linkend} 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Εάν εντοπίσετε οποιοδήποτε πρόβλημα, μη διστάσετε να το αναφέρετε στον {issuetracker}ιχνηλάτη ζητημάτων μας{linkend}. Και εάν θέλετε να συμμετέχετε, ελάτε στην {designteam}ομάδα σχεδιασμού μας{linkend}!",
    "Change color" : "Αλλαγή χρώματος",
    "Select a custom color" : "Επιλογή προσαρμοσμένου χρώματος",
    "Reset to default" : "Επαναφορά στα προεπιλεγμένα",
    "Upload" : "Μεταφόρτωση",
    "Remove background image" : "Αφαίρεση εικόνας παρασκηνίου",
    "Loading preview…" : "Φόρτωση προεπισκόπησης ...",
    "Admin" : "Διαχειριστής",
    "Name cannot be empty" : "Το όνομα δεν μπορεί να είναι κενό",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Σε ορισμένες περιπτώσεις, οι συντομεύσεις πληκτρολογίου μπορεί να επηρεάσουν τα εργαλεία προσβασιμότητας. Για να επιτρέψετε τη σωστή εστίαση στο εργαλείο σας, μπορείτε να απενεργοποιήσετε όλες τις συντομεύσεις πληκτρολογίου εδώ. Αυτό θα απενεργοποιήσει επίσης όλες τις διαθέσιμες συντομεύσεις στις εφαρμογές.",
    "Pick from Files" : "Επιλέξτε από αρχεία",
    "Default image" : "Προεπιλεγμένη εικόνα",
    "Custom color" : "Προσαρμοσμένο χρώμα",
    "Plain background" : "Απλό παρασκήνιο",
    "Insert from {productName}" : "Εισαγωγή από {productName}",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης",
    "https://…" : "https://…",
    "Upload new login background" : "Μεταφόρτωση νέου παρασκηνίου εισόδου",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Αν και μπορείτε να επιλέξετε και να προσαρμόσετε την εγκατάστασή σας, οι χρήστες μπορούν να αλλάξουν το φόντο και τα χρώματά τους. Εάν θέλετε να επιβάλετε την προσαρμογή σας, μπορείτε να επιλέξετε αυτό το κουτί.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Εγκαταστήστε την επέκταση PHP Imagemagick με υποστήριξη SVG εικόνων, για να γίνει αυτόματη δημιουργία favicon βασισμένο πάνω στο μεταφορτωμένο λογότυπο και χρώμα."
},
"nplurals=2; plural=(n != 1);");

==> php80-nextcloud-28.0.2.tgz: share/nextcloud/apps/theming/l10n/el.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Το όνομα που δόθηκε είναι πολύ μεγάλο",
    "The given web address is too long" : "Η διεύθυνση ιστοσελίδας που δόθηκε είναι πολύ μεγάλη.",
    "The given web address is not a valid URL" : "Η διεύθυνση ιστοχώρου δεν είναι έγκυρη URL",
    "The given legal notice address is too long" : "Η διεύθυνση ειδοποίησης είναι πολύ μεγάλη",
    "The given legal notice address is not a valid URL" : "Η διεύθυνση νομικής ειδοποίησης δεν είναι έγκυρη διεύθυνση URL",
    "The given privacy policy address is too long" : "Η διεύθυνση πολιτικής απορρήτου είναι πολύ μεγάλη",
    "The given privacy policy address is not a valid URL" : "Η διεύθυνση πολιτικής απορρήτου δεν είναι έγκυρη διεύθυνση URL",
    "The given slogan is too long" : "Το ρητό που δόθηκε είναι πολύ μεγάλο",
    "The given color is invalid" : "Δόθηκε μη έγκυρο χρώμα",
    "Saved" : "Αποθηκεύτηκαν",
    "The file was uploaded" : "Το αρχείο μεταφορτώθηκε",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία upload_max_filesize στο php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Το μεταφορτωμένο αρχείο υπερβαίνει την οδηγία MAX_FILE_SIZE που καθορίστηκε στην φόρμα HTML.",
    "The file was only partially uploaded" : "Το αρχείο μεταφορτώθηκε εν μέρει",
    "No file was uploaded" : "Δεν μεταφορτώθηκε κάποιο αρχείο",
    "Missing a temporary folder" : "Λείπει κάποιος προσωρινός φάκελος",
    "Could not write file to disk" : "Αδυναμία εγγραφής αρχείου στον δίσκο",
    "A PHP extension stopped the file upload" : "Ένα πρόσθετο PHP διέκοψε την μεταφόρτωση του αρχείου",
    "No file uploaded" : "Δεν έχει μεταφορτωθεί αρχείο",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Χρησιμοποιείτε ήδη προσαρμοσμένο θέμα. Οι ρυθμίσεις της εφαρμογής Θέματα μπορεί να αντικατασταθούν από αυτό.",
    "Theming" : "Προσαρμογή θέματος",
    "Appearance and accessibility" : "Εμφάνιση και προσβασιμότητα",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Το άρθρωμα PHP \"imagick\" δεν είναι ενεργοποιημένο αν και η εφαρμογή θεματοποίησης είναι. Για να λειτουργήσει σωστά η δημιουργία favicon, πρέπει να εγκαταστήσετε και να ενεργοποιήσετε αυτό το άρθρωμα.",
    "Dark theme with high contrast mode" : "Σκούρο θέμα με λειτουργία υψηλής αντίθεσης",
    "Enable dark high contrast mode" : "Ενεργοποίηση σκοτεινής λειτουργίας υψηλής αντίθεσης",
    "Similar to the high contrast mode, but with dark colours." : "Παρόμοιο με τη λειτουργία υψηλής αντίθεσης, αλλά με σκούρα χρώματα.",
    "Dark theme" : "Σκούρο θέμα",
    "Enable dark theme" : "Ενεργοποίηση σκούρου θέματος",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Ένα σκούρο θέμα που διευκολύνει τα μάτια σας μειώνοντας τη συνολική ακτινοβολία και φωτεινότητα.",
    "System default theme" : "Προεπιλεγμένο θέμα συστήματος",
    "Enable the system default" : "Ενεργοποίηση προεπιλογής συστήματος",
    "Using the default system appearance." : "Χρήση της προεπιλεγμένης εμφάνισης του συστήματος.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "Enable dyslexia font" : "Ενεργοποίηση γραμματοσειράς για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη λάθη που προκαλεί η δυσλεξία στην ανάγνωση",
    "High contrast mode" : "Λειτουργία υψηλής αντίθεσης",
    "Enable high contrast mode" : "Ενεργοποίηση λειτουργίας υψηλής αντίθεσης",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Λειτουργία με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Light theme" : "Φωτεινό θέμα",
    "Enable the default light theme" : "Ενεργοποίηση φωτεινού θέματος",
    "The default light appearance." : "Η προεπιλεγμένη ανοιχτόχρωμη εμφάνιση.",
    "Legal notice" : "Νομική ειδοποίηση",
    "Privacy policy" : "Πολιτική Απορρήτου",
    "Adjust the Nextcloud theme" : "Προσαρμόστε το θέμα του Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Η προσαρμογή θέματος καθιστά δυνατή την εύκολη προσαρμογή της εμφάνισης της εγκατάστασής σας καθώς και των υποστηριζόμενων πελατών. Θα είναι ορατή για όλους τους χρήστες.",
    "Advanced options" : "Επιλογές για προχωρημένους",
    "Name" : "Όνομα",
    "Web link" : "Σύνδεσμος ιστού",
    "a safe home for all your data" : "μια ασφαλής τοποθεσία για όλα σας τα δεδομένα",
    "Slogan" : "Ρητό",
    "Color" : "Χρώμα",
    "Logo" : "Λογότυπο",
    "Upload new logo" : "Μεταφόρτωση νέου λογοτύπου",
    "Background and login image" : "Παρασκήνιο και εικόνα εισόδου",
    "Legal notice link" : "Σύνδεσμος νομικής ειδοποίησης",
    "Privacy policy link" : "Σύνδεσμος πολιτικής απορρήτου",
    "Header logo" : "Λογότυπο επικεφαλίδας",
    "Upload new header logo" : "Μεταφόρτωση νέου λογοτύπου επικεφαλίδας",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Μεταφόρτωση νέου favicon",
    "User settings" : "Ρυθμίσεις χρήστη",
    "Disable user theming" : "Απενεργοποίηση θεμάτων χρήστη",
    "Background" : "Φόντο",
    "Set a custom background" : "Ορισμός προσαρμοσμένου φόντου",
    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Σε ορισμένες περιπτώσεις, οι συντομεύσεις πληκτρολογίου μπορεί να επηρεάσουν τα εργαλεία προσβασιμότητας. Για να επιτρέψετε τη σωστή εστίαση στο εργαλείο σας, μπορείτε να απενεργοποιήσετε όλες τις συντομεύσεις πληκτρολογίου εδώ. Αυτό θα απενεργοποιήσει επίσης όλες τις διαθέσιμες συντομεύσεις στις εφαρμογές.",
    "Disable all keyboard shortcuts" : "Απενεργοποίηση των συντομεύσεων πληκτρολογίου",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η  πρόσβαση από όλους είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με τις {guidelines}Προδιαγραφές πρόσβασης περιεχομένου Ιστού{linkend} 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Εάν εντοπίσετε οποιοδήποτε πρόβλημα, μη διστάσετε να το αναφέρετε στον {issuetracker}ιχνηλάτη ζητημάτων μας{linkend}. Και εάν θέλετε να συμμετέχετε, ελάτε στην {designteam}ομάδα σχεδιασμού μας{linkend}!",
    "Move up" : "Μετακίνηση επάνω",
    "Move down" : "Μετακίνηση Κάτω",
    "Change color" : "Αλλαγή χρώματος",
    "Reset to default" : "Επαναφορά στα προεπιλεγμένα",
    "Upload" : "Μεταφόρτωση",
    "Remove background image" : "Αφαίρεση εικόνας παρασκηνίου",
    "Select a custom color" : "Επιλογή προσαρμοσμένου χρώματος"
},
"nplurals=2; plural=(n != 1);");
